# Security Policy

## Supported Versions

Below shows the list of supported version for the mistyfy library

| Version | Supported          |
| ------- | ------------------ |
| 2.0.4   | :white_check_mark: |
| 2.0.3   | :white_check_mark: |
| 2.0.2   | :white_check_mark: |
| 2.0.1   | :x:                |
| 2.0.0   | :x:                |
| 1.0.1   | :x:                |
| 1.0.0   | :x:                |

## Reporting a Vulnerability

Please for any security related issue. Send us an email at support@elfapp.website
